RateLimitError class

429 — rate limited. retryAfter carries seconds to wait when provided.

Inheritance

Constructors

RateLimitError(String message, {int? retryAfter, num? balance, num? freeRemaining, Map<String, dynamic>? body})
const

Properties

balance num?
final
body Map<String, dynamic>?
Decoded JSON error body, when available.
finalinherited
code String?
finalinherited
freeRemaining num?
final
hashCode int
The hash code for this object.
no setterinherited
message String
finalinherited
retryAfter int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited