ReachSseEvent class

A single Server-Sent Event emitted by a lead-finder job stream.

Constructors

ReachSseEvent(String? event, dynamic data)
const

Properties

data → dynamic
The data: payload — a decoded JSON object/array, or the raw string.
final
event String?
The SSE event: name, if any.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited