current property
int?
get
current
Usage against that cap when the call was refused.
Implementation
int? get current => (body?['current'] as num?)?.toInt();
Usage against that cap when the call was refused.
int? get current => (body?['current'] as num?)?.toInt();